#include "g_visu.h"
#include "v_view.h"
#include "t_menu.h"
#include "v_menu.h"

extern Display *display;
extern Window T_window;
extern XEvent V_event;

int T_event ()
{
int x, y;
static int witchIcon;

	switch (V_event.type) {
		case Expose:
			T_setMenu();
			T_drawMenu();
			T_refresh();
			break;
		case ButtonPress:
			x = V_event.xbutton.x;
			y = V_event.xbutton.y;
			witchIcon = T_clickedIcon (x, y);
			switch (witchIcon) {
				case TR_PGUP: 
					T_drawIcon(TR_PGUP, ON); 
					break;
				case TR_PGDN: 
					T_drawIcon(TR_PGDN, ON); 
					break;
				case TR_LNUP: 
					T_drawIcon(TR_LNUP, ON); 
					break;
				case TR_LNDN: 
					T_drawIcon(TR_LNDN, ON); 
					break;
				case TR_EXIT: 
					T_drawIcon(TR_EXIT, ON); 
					break;
			}
			break;
		case ButtonRelease:
			switch (witchIcon) {
				case TR_PGUP: 
					T_pageUp (); 
					T_drawIcon(TR_PGUP, OFF); 
					break;
				case TR_PGDN: 
					T_pageDn (); 
					T_drawIcon(TR_PGDN, OFF); 
					break;
				case TR_LNUP: 
					T_lineUp (); 
					T_drawIcon(TR_LNUP, OFF); 
					break;
				case TR_LNDN: 
					T_lineDn (); 
					T_drawIcon(TR_LNDN, OFF); 
					break;
				case TR_EXIT: 
					T_initText(); 
					T_drawIcon(TR_EXIT, OFF); 
					break;
			}
	}
	return NO_WINDOW_ACTION;
}
